@@ -21,19 +21,19 @@
 #include <gtk/gtk.h>
 #include <libbiji/libbiji.h>
 
-#include "bjb-bijiben.h"
+#include "bjb-application.h"
 
 int
 main (int argc, char *argv[])
 {
-  Bijiben *app;
+  BjbApplication *app;
   int status;
 
   bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  app = bijiben_new ();
+  app = bjb_application_new ();
   status = g_application_run (G_APPLICATION (app), argc, argv);
   g_object_unref (app);
 
