@@ -21,11 +21,11 @@
 #define _LIBBIJI_INSIDE_H
 
 
-#include "biji-collection.h"
 #include "biji-date-time.h"
 #include "biji-item.h"
 #include "biji-marshalers.h"
-#include "biji-note-book.h"
+#include "biji-manager.h"
+#include "biji-notebook.h"
 #include "biji-note-obj.h"
 #include "biji-string.h"
 #include "biji-tracker.h"
